Learn R Programming

Fgmutils (version 0.9.4)

avaliaVolumeAvancado: evaluates Volume Advanced

Description

this function performs an assessment of estimates of a variable as the forcefulness with expected

Usage

avaliaVolumeAvancado(base, mapeamento = list(dap1 = "dap1", dap2 = "dap2", ht1  = "ht1", ht2 = "ht2"), modelos = NULL, salvar = NULL, graficos = NULL, estatisticas = NULL, forcePredict = F, dividirEm = "parcela", percentualDeTreino = 0.7, agruparPor = "parcela", fnCalculaVolume = calculaVolumeDefault)

Arguments

base
data.frame with data
mapeamento
name of field eight and diameter
modelos
list of exclusive for base models
salvar
list of param to save the files
graficos
list of param to plot graphics
estatisticas
list of param to caclc estatistics
forcePredict
force the calculation without using predict?
dividirEm
how divide the base in training and validation
percentualDeTreino
how many percent will stay in the training group?
agruparPor
name field of base is group of individuals
fnCalculaVolume
list of estatistics results

Value

will be returned a result of statistics and ranking of volume