Learn R Programming

Fgmutils (version 0.9.4)

contemParametros: which parameters are missing?

Description

this function checks whether the labels of the parameters list to move to the functions is sufficient

Usage

contemParametros(funcoes, parametro, addParametro = c(), addArgs = c(), exclui3pontos = T)

Arguments

funcoes
is a or set of functions whose param will be verify
parametro
is list whose labels is name of param in funcoes, list of args to funcoes ex list(a="1", b="2")
addParametro
list of param included
addArgs
more param required
exclui3pontos
verify por ... ? in f<-function(a, ...)

Value

will be returned the parameters that have not been reported in parametro and addParametro