Learn R Programming

Fgmutils (version 0.2)

criaDadosPareados: Create Date Paired

Description

paired a dataframe

Usage

criaDadosPareados(dataFrame, campoChave, campoComparacao, camposPareados,
  camposNaoPareados)

Arguments

dataFrame
dataframe that you want to pair dataFrame must contain columns cod_id, ANO_MEDICAO1, ANO_MEDICAO2, DAP1, DAP2, HT1, HT2, ID_PROJETO
campoChave
character the column that will be paired
campoComparacao
character the field used to compare the period of change
camposPareados
vector the fields that will be paired exemple CampoesPareados=c(dap,ht)
camposNaoPareados
the fields he wants to be present without the paired

Value

  • will be returned a dataframe containing columns cod_id, ANO_MEDICAO1, ANO_MEDICAO2, DAP1, DAP2, HT1, HT2, ID_PROJETO