Learn R Programming

Fgmutils (version 0.9.4)

criaModeloGenerico: Create function with generic model

Description

This function creates a generic model that will be a funcao that has parameters for the variables that can be mapped to each different base. her return will be a generic model that should be mapped to be used by the function avaliaEstimativas

Usage

criaModeloGenerico(nome, formula, funcaoRegressao, variaveis, palpite = NULL, maisParametros = NULL, requires = NULL)

Arguments

nome
is the name of model
formula
is the string formula begin with y2~y1
funcaoRegressao
is the function that will make the regression, ex.: 'nlsLM'
variaveis
list variables that are present in the model that are field database
palpite
param start of funcaoRegressao
maisParametros
string add in funcaoRegressao, ex lm(y2~y1, data=base, maisParametros)
requires
list of string of packges used to work with funcaoRegressao

Value

will be returned function with generic model to map to a base