Learn R Programming

Fgmutils (version 0.9.4)

geraModelo: Generates function to work with a model

Description

this function generates unique model given: A formula and a guess (optional: name, funcaoRegressao, maisParametros, requires - proidido: custom)] or[A string saying how the return will be obtained eg custom = "lm (dap2 dap1 ~ * b 0)" (if the formula can not be passed just go empty, ex .: formula = "")]

Usage

geraModelo(nome = "modelo sem nome", formula, funcaoRegressao = "nlsLM", palpite = NULL, maisParametros = NULL, requires = NULL, customizado = NULL)

Arguments

nome
is the name of model
formula
is the string formula begin with y2~y1
funcaoRegressao
is the function that will make the regression, ex.: 'nlsLM'
palpite
param start of funcaoRegressao
maisParametros
string add in funcaoRegressao, ex lm(y2~y1, data=base, maisParametros)
requires
list of string of packges used to work with funcaoRegressao
customizado
if you want to write as the return will be obtained report as a string

Value

will be returned a function with exclusive model