Rdocumentation
powered by
Learn R Programming
Fgmutils (version 0.9.4)
getBaseOfAjust: get database Of Ajust
Description
this function returns the database used in the setting
Usage
getBaseOfAjust(ajuste)
Arguments
ajuste
is ajust obtained a function like lm or nlsLM
Value
will be returned a string which is the database of ajust