Learn R Programming

Fgmutils (version 0.9.4)

getColumnsOfAjust: get Columns used in Ajust

Description

this function returns an array with the column names that are on the model and reported basis or basis used in ajust

Usage

getColumnsOfAjust(ajuste, dfDados = NULL, excludeY1andY2 = T)

Arguments

ajuste
is ajust obtained a function like lm or nlsLM
dfDados
data.frame optional
excludeY1andY2
delete Y1 and Y2 fields? del formula(y1~y2...)

Value

will be returned list of columns used in ajust