Rdocumentation
powered by
Learn R Programming
Fgmutils (version 0.9.4)
getFormulaExclusivaOfAjust: get Formula Exclusive Of Ajust
Description
this function returns the formula of the model used in ajust
Usage
getFormulaExclusivaOfAjust(ajuste)
Arguments
ajuste
is ajust obtained a function like lm or nlsLM
Value
will be returned a string which is the formula of ajust