Learn R Programming

Fgmutils (version 0.9.4)

getGraphicObservadoXEstimado: Get Graphic Observed X Estimated

Description

this function display/save a graphic scatter.smooth illustrating the difference between the observed and estimated

Usage

getGraphicObservadoXEstimado(titulo = "observadoXestimado", nome = "observadoXestimado", observado, estimado, showTestF = TRUE, save = NULL, labsX = "observado", labsy = "estimado", vetorial = T, ...)

Arguments

titulo
is the title graphic
nome
name of file case save
observado
list containing the observations of variable
estimado
list containing estimates of variable
showTestF
draw results of test F in graphic?
save
If you want to save enter the directory as a string
labsX
label x
labsy
label y
vetorial
save picture in vector type? (Default TRUE)
...
only for compatibility with other functions