Learn R Programming

Fgmutils (version 0.9.4)

getggplot2GraphicObservadoXEstimado: Get ggplot2 Grapic observed versus estimated

Description

this function displays/saves/returns a Graphical ggplot2 illustrating the difference between the observed and estimated

Usage

getggplot2GraphicObservadoXEstimado(titulo = "observadoXestimado", nome = "observadoXestimado", observado, estimado, identificadorIndividual = NULL, identificadorGrupal = NULL, showTestF = TRUE, TestFposition = 4, titleIdentificadorGrupal = NULL, save = NULL, labsX = "observado", labsy = "estimado", nomeParaExibir = NULL, environ = 1, extensao = ".png", ...)

Arguments

titulo
is the title graphic
nome
name of file case save
observado
list containing the observations of variable
estimado
list containing estimates of variable
identificadorIndividual
list containing 'id' of individuals
identificadorGrupal
list containing group of individuals
showTestF
draw results of test F in graphic?
TestFposition
show one of the four corners of the graph clockwise
titleIdentificadorGrupal
title of Legend of the groups
save
If you want to save enter the directory as a string
labsX
label x
labsy
label y
nomeParaExibir
This is the name to display the graph as a function after the completion of this
environ
environment in which the function to display the ggplot2 must be saved
extensao
type of image that will be saved
...
only for compatibility with other functions

Value

will be returned the graphical generated by ggplot2