Learn R Programming

Fgmutils (version 0.6)

gravaDocResultado: Records doc result

Description

this function records the result in a docx file

Usage

gravaDocResultado(dfResultado, arquivo, template)

Arguments

dfResultado
a dataset to record in doc
arquivo
the name that you want to file
template
"character" value, it represents the filename of the docx file used as a template.