Learn R Programming

Fgmutils (version 0.6)

gravaResultado: Records doc result

Description

this function records the result in a docx file

Usage

gravaResultado(resultado, arquivo, modelo, template = "template.docx")

Arguments

resultado
table with the results of statistical functions available in avaliaAjuste function
arquivo
the name that you want to file
modelo
Rdata file
template
"character" value, it represents the filename of the docx file used as a template.