Learn R Programming

Fgmutils (version 0.9.4)

projectBaseOriented: Project Base Oriented

Description

this function build a list of dataframe with projects of ages between 'firstAge' and 'lastAge' params

Usage

projectBaseOriented(firstAge = NaN, lastAge = NaN, fitDAP, fitHT, base, mapper = list(age1 = "idadearred1", dap1 = "dap1", dap2 = "dap2", ht1 = "ht1", ht2 = "ht2"), calcVolume = calculaVolumeDefault, forcePredict = F)

Arguments

firstAge
the first age to predict
lastAge
the last age to predict
fitDAP
a fit get function inherit lm to DAP
fitHT
a fit get function inherit lm to HT
base
data base
mapper
the label used in fields to age, dap and ht
calcVolume
function to calc volume
forcePredict
force calc base coefficients or se predict()?

Value

will be returned a list of volume predict to ages in dataframe and/or param