atualizaCampoBase: updated base field
Description
this function update certain fields in a dataframe, based on the provided keyUsage
atualizaCampoBase(camposAtualizar, baseAgrupada, baseAtualizar, keys)
Arguments
camposAtualizar
is the vector you want to update
baseAgrupada
It is the database that contains the data you want to update on dataframe
baseAtualizar
It is dataframe that you want to change fields
keys
are the keys of the table that will be used in the compare
Value
- baseAtualizar with the updated fields according to baseAgrupada