avaliaEstimativas: calculate Estimates
Description
given a list of observations and an estimated list of these observations this function evaluates how close it is the estimated value of observed and saves the differences
Usage
avaliaEstimativas(observado, estimado, estatisticas, ajuste = NULL, graficos = NULL, salvarEm = NULL, nome = "observadoXestimado")
Arguments
observado
list containing the observations of variable
estimado
list containing estimates of variable
estatisticas
list of arg to calc estatistics
ajuste
is ajust obtained a function like lm or nlsLM
graficos
list of arg to plot graphics
salvarEm
directory to save files
nome
name of files will be save