Rdocumentation
powered by
Learn R Programming
Fgmutils (version 0.9.4)
criaModeloExclusivo: Create Exclusive Model for a database
Description
this function returns a unique model is variable receive each mapeda variable ex .: criaModeloExclusivo (modeloCamposLeite, c ("age1", "age2", "bai1", "s"))
Usage
criaModeloExclusivo(modeloGenerico, variaveis, palpite = NULL)
Arguments
modeloGenerico
model of pattern criaModeloGenerico
variaveis
list of name fields (strings) in database and model, the order of variables matter
palpite
string containing start values of function of regression
Value
will be returned a function with exclusive model