getGraphicHistogram: Get Histogram of Residuals absolute
Description
this function displays/saves a histogram graph illustrating the frequency of waste in classes
Usage
getGraphicHistogram(titulo = "residuos", nome = "observadoXestimado", estatisticas, save = NULL, vetorial = T, ...)
Arguments
titulo
is the title graphic
nome
name of file case save
estatisticas
data.frame containing field 'residuo'
save
If you want to save enter the directory as a string
vetorial
save picture in vector type? (Default TRUE)
...
only for compatibility with other functions