Description
this function is the replacement predict, she tries to predict if the return zero predict it calculates the prediction with the coefficients reported in the parameter setting
Usage
predizer(ajuste, newdata, force = FALSE, ...)
Arguments
ajuste
is ajust obtained a function like lm or nlsLM
newdata
dataframe where fields will be update
force
force the calculation without using predict?
...
only for compatibility with other functions
Value
will be returned list of values predicts